==> developer-center-api-2.4.6-20170727.041824-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/appextra/AppExtraDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.appextra;

import java.io.Serializable;
import java.util.Date;

public class AppExtraDto implements Serializable{

	/**
	 */
	private static final long serialVersionUID = 1L;
	
	private Long id;
    private Long appId;
    private String shareLogo;
    private String shareButtonName;
    private String wakeupAppLink;
    private Date gmtCreate;
    private Date gmtModified;
    private String alarmPhone;
    private String entranceDesc;
    private String callLoginProgram;
    private String appPerson;
    private String appType;
    private String shareAndroidLink;
    private String shareAndroidLinkActivity;
    private String shareIosLink;
    private String shareIosLinkActivity;
    private Boolean isDuibaShare;
    private String shareImage;
    private Boolean isInfoGet;
    private String shareLandUrl;
    private String addCreditsUrl;
    private String shareDesc;
    private String shareProgram;
    private String navProgram;
    
    private Boolean         toBeInsert;

    private Boolean         toBeUpdate;

    public Boolean getToBeInsert() {
        if (toBeInsert == null) {
            toBeInsert = false;
        }
        return toBeInsert;
    }

    public Boolean getToBeUpdate() {
        if (toBeUpdate == null) {
            toBeUpdate = false;
        }
        return toBeUpdate;
    }

    public void setToBeInsert(Boolean toBeInsert) {
        this.toBeInsert = toBeInsert;
    }

    public void setToBeUpdate(Boolean toBeUpdate) {
        this.toBeUpdate = toBeUpdate;
    }
    
    public AppExtraDto(boolean init4insert) {
        if (init4insert) {
            toBeInsert = true;
            gmtCreate = new Date();
            gmtModified = new Date();
        }
    }

    public AppExtraDto() {
    }

    public AppExtraDto(Long id) {
        this.id = id;
        this.gmtModified = new Date();
        toBeUpdate = true;
        toBeInsert = false;
    }
    
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getShareLogo() {
		return shareLogo;
	}
	public void setShareLogo(String shareLogo) {
		this.shareLogo = shareLogo;
	}
	public String getShareButtonName() {
		return shareButtonName;
	}
	public void setShareButtonName(String shareButtonName) {
		this.shareButtonName = shareButtonName;
	}
	public String getWakeupAppLink() {
		return wakeupAppLink;
	}
	public void setWakeupAppLink(String wakeupAppLink) {
		this.wakeupAppLink = wakeupAppLink;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	public String getAlarmPhone() {
		return alarmPhone;
	}
	public void setAlarmPhone(String alarmPhone) {
		this.alarmPhone = alarmPhone;
	}
	public String getEntranceDesc() {
		return entranceDesc;
	}
	public void setEntranceDesc(String entranceDesc) {
		this.entranceDesc = entranceDesc;
	}
	public String getCallLoginProgram() {
		return callLoginProgram;
	}
	public void setCallLoginProgram(String callLoginProgram) {
		this.callLoginProgram = callLoginProgram;
	}
	public String getAppPerson() {
		return appPerson;
	}
	public void setAppPerson(String appPerson) {
		this.appPerson = appPerson;
	}
	public String getAppType() {
		return appType;
	}
	public void setAppType(String appType) {
		this.appType = appType;
	}
	public String getShareAndroidLink() {
		return shareAndroidLink;
	}
	public void setShareAndroidLink(String shareAndroidLink) {
		this.shareAndroidLink = shareAndroidLink;
	}
	public String getShareAndroidLinkActivity() {
		return shareAndroidLinkActivity;
	}
	public void setShareAndroidLinkActivity(String shareAndroidLinkActivity) {
		this.shareAndroidLinkActivity = shareAndroidLinkActivity;
	}
	public String getShareIosLink() {
		return shareIosLink;
	}
	public void setShareIosLink(String shareIosLink) {
		this.shareIosLink = shareIosLink;
	}
	public String getShareIosLinkActivity() {
		return shareIosLinkActivity;
	}
	public void setShareIosLinkActivity(String shareIosLinkActivity) {
		this.shareIosLinkActivity = shareIosLinkActivity;
	}
	public Boolean getIsDuibaShare() {
		return isDuibaShare;
	}
	public void setIsDuibaShare(Boolean isDuibaShare) {
		this.isDuibaShare = isDuibaShare;
	}
	public String getShareImage() {
		return shareImage;
	}
	public void setShareImage(String shareImage) {
		this.shareImage = shareImage;
	}
	public Boolean getIsInfoGet() {
		return isInfoGet;
	}
	public void setIsInfoGet(Boolean isInfoGet) {
		this.isInfoGet = isInfoGet;
	}
	public String getShareLandUrl() {
		return shareLandUrl;
	}
	public void setShareLandUrl(String shareLandUrl) {
		this.shareLandUrl = shareLandUrl;
	}
	public String getAddCreditsUrl() {
		return addCreditsUrl;
	}
	public void setAddCreditsUrl(String addCreditsUrl) {
		this.addCreditsUrl = addCreditsUrl;
	}
	public String getShareDesc() {
		return shareDesc;
	}
	public void setShareDesc(String shareDesc) {
		this.shareDesc = shareDesc;
	}
	public String getShareProgram() {
		return shareProgram;
	}
	public void setShareProgram(String shareProgram) {
		this.shareProgram = shareProgram;
	}
	public String getNavProgram() {
		return navProgram;
	}
	public void setNavProgram(String navProgram) {
		this.navProgram = navProgram;
	}

}

==> developer-center-api-3.6.70-sources.jar: cn/com/duiba/developer/center/api/domain/dto/appextra/AppExtraDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.appextra;

import java.io.Serializable;
import java.util.Date;

public class AppExtraDto implements Serializable{

	/**
	 */
	private static final long serialVersionUID = 1L;
	
	private Long id;
    private Long appId;
    private String shareLogo;
    private String shareButtonName;
    private String wakeupAppLink;
    private Date gmtCreate;
    private Date gmtModified;
    private String alarmPhone;
    private String entranceDesc;
    private String callLoginProgram;
    private String appPerson;
    private String appType;
    private String shareAndroidLink;
    private String shareAndroidLinkActivity;
    private String shareIosLink;
    private String shareIosLinkActivity;
    private Boolean isDuibaShare;
    private String shareImage;
    private Boolean isInfoGet;
    private String shareLandUrl;
    private String addCreditsUrl;
    private String shareDesc;
    private String shareProgram;
    private String navProgram;
    private String taskListUrl;
	private String flowViewTime;//流量策略展示时间
    
    private Boolean         toBeInsert;

    private Boolean         toBeUpdate;

    public Boolean getToBeInsert() {
        if (toBeInsert == null) {
            toBeInsert = false;
        }
        return toBeInsert;
    }

    public Boolean getToBeUpdate() {
        if (toBeUpdate == null) {
            toBeUpdate = false;
        }
        return toBeUpdate;
    }

    public void setToBeInsert(Boolean toBeInsert) {
        this.toBeInsert = toBeInsert;
    }

    public void setToBeUpdate(Boolean toBeUpdate) {
        this.toBeUpdate = toBeUpdate;
    }
    
    public AppExtraDto(boolean init4insert) {
        if (init4insert) {
            toBeInsert = true;
            gmtCreate = new Date();
            gmtModified = new Date();
        }
    }

    public AppExtraDto() {
    }

    public AppExtraDto(Long id) {
        this.id = id;
        this.gmtModified = new Date();
        toBeUpdate = true;
        toBeInsert = false;
    }
    
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getShareLogo() {
		return shareLogo;
	}
	public void setShareLogo(String shareLogo) {
		this.shareLogo = shareLogo;
	}
	public String getShareButtonName() {
		return shareButtonName;
	}
	public void setShareButtonName(String shareButtonName) {
		this.shareButtonName = shareButtonName;
	}
	public String getWakeupAppLink() {
		return wakeupAppLink;
	}
	public void setWakeupAppLink(String wakeupAppLink) {
		this.wakeupAppLink = wakeupAppLink;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	public String getAlarmPhone() {
		return alarmPhone;
	}
	public void setAlarmPhone(String alarmPhone) {
		this.alarmPhone = alarmPhone;
	}
	public String getEntranceDesc() {
		return entranceDesc;
	}
	public void setEntranceDesc(String entranceDesc) {
		this.entranceDesc = entranceDesc;
	}
	public String getCallLoginProgram() {
		return callLoginProgram;
	}
	public void setCallLoginProgram(String callLoginProgram) {
		this.callLoginProgram = callLoginProgram;
	}
	public String getAppPerson() {
		return appPerson;
	}
	public void setAppPerson(String appPerson) {
		this.appPerson = appPerson;
	}
	public String getAppType() {
		return appType;
	}
	public void setAppType(String appType) {
		this.appType = appType;
	}
	public String getShareAndroidLink() {
		return shareAndroidLink;
	}
	public void setShareAndroidLink(String shareAndroidLink) {
		this.shareAndroidLink = shareAndroidLink;
	}
	public String getShareAndroidLinkActivity() {
		return shareAndroidLinkActivity;
	}
	public void setShareAndroidLinkActivity(String shareAndroidLinkActivity) {
		this.shareAndroidLinkActivity = shareAndroidLinkActivity;
	}
	public String getShareIosLink() {
		return shareIosLink;
	}
	public void setShareIosLink(String shareIosLink) {
		this.shareIosLink = shareIosLink;
	}
	public String getShareIosLinkActivity() {
		return shareIosLinkActivity;
	}
	public void setShareIosLinkActivity(String shareIosLinkActivity) {
		this.shareIosLinkActivity = shareIosLinkActivity;
	}
	public Boolean getIsDuibaShare() {
		return isDuibaShare;
	}
	public void setIsDuibaShare(Boolean isDuibaShare) {
		this.isDuibaShare = isDuibaShare;
	}
	public String getShareImage() {
		return shareImage;
	}
	public void setShareImage(String shareImage) {
		this.shareImage = shareImage;
	}
	public Boolean getIsInfoGet() {
		return isInfoGet;
	}
	public void setIsInfoGet(Boolean isInfoGet) {
		this.isInfoGet = isInfoGet;
	}
	public String getShareLandUrl() {
		return shareLandUrl;
	}
	public void setShareLandUrl(String shareLandUrl) {
		this.shareLandUrl = shareLandUrl;
	}
	public String getAddCreditsUrl() {
		return addCreditsUrl;
	}
	public void setAddCreditsUrl(String addCreditsUrl) {
		this.addCreditsUrl = addCreditsUrl;
	}
	public String getShareDesc() {
		return shareDesc;
	}
	public void setShareDesc(String shareDesc) {
		this.shareDesc = shareDesc;
	}
	public String getShareProgram() {
		return shareProgram;
	}
	public void setShareProgram(String shareProgram) {
		this.shareProgram = shareProgram;
	}
	public String getNavProgram() {
		return navProgram;
	}
	public void setNavProgram(String navProgram) {
		this.navProgram = navProgram;
	}

	public String getFlowViewTime() {
		return flowViewTime;
	}

	public void setFlowViewTime(String flowViewTime) {
		this.flowViewTime = flowViewTime;
	}

	public String getTaskListUrl() {
		return taskListUrl;
	}

	public void setTaskListUrl(String taskListUrl) {
		this.taskListUrl = taskListUrl;
	}
}
